#!perl
use 5.006;
use strict;
use warnings;
use Test::More;

our $VERSION = '0.05';

use GCC::Builtins qw/:all/;

my $res = parity(2);
my $expected = "1";
if( $expected =~ /^([+-]?)(?=\d|\.\d)\d*(\.\d*)?([Ee]([+-]?\d+))?$/ ){
	my $dif = abs($res-$expected);
	ok($dif<1e-09, "called parity(2) returned ($res) and expected ($expected) values differ ($dif) by less than 1e-09.");
} else {
	is($res, $expected, "called parity(2) returned ($res) and expected ($expected) values are identical.");
}
diag("copy-this-expected-value 'parity' => '$res',");

done_testing();
